package helper

const (
	// RootAnnoName is prefix for all kubedog annotations.
	RootAnnoName = "helmwave.app/"
)
